import List from '@mui/material/List';
import { makeStyles } from '@material-ui/core'
import { useEffect,useRef,useCallback } from 'react';
import { useSelector, useDispatch } from 'react-redux';

import AlertInfo from '../../../reusableComponents/AlertInfo'
import ChatItem from './ChatItem';
import { notification,playNotificationWithoutPermission,sortByRecent } from '../../../../helpers'
import { getStateMemo } from '../../../../redux/chats/selector'
import { getChatMemo } from '../../../../redux/chat/selector'
import { asyncGetChatById } from '../../../../redux/chat/operations'
import { asyncGetChats } from '../../../../redux/chats/operations';
import { actionRightIsOpen,actionScrollChat } from '../../../../redux/control/action'
import { TChats } from '../../../../typescript/redux/chats/types';
import { prodBaseURL,refreshAppTime } from '../../../../helpers';

const useStyles = makeStyles({
  list: {
    width: '100%',
    maxHeight: '93vh',
    overflowY: 'scroll',
  '&::-webkit-scrollbar': {
    width: '0.4em'
  },
  '&::-webkit-scrollbar-track': {
    boxShadow: 'inset 0 0 6px rgba(0,0,0,0.00)',
    webkitBoxShadow: 'inset 0 0 6px rgba(0,0,0,0.00)',
    backgroundColor: '#eceeec',
  },
  '&::-webkit-scrollbar-thumb': {
    backgroundColor: '#ccc8c8',
    },
  "&::-webkit-scrollbar-thumb:focus": {
    backgroundColor: "#959595",
          },
  "&::-webkit-scrollbar-thumb:active": {
    backgroundColor: "#959595",
    },
  },
})

interface IChatsList {
  sort: boolean,
}

const ChatsList = ({sort}:IChatsList) => {
  const classes = useStyles()
  const dispatch = useDispatch()
  const chatsRef = useRef<any>(null)
  const { total, chats } = useSelector(getStateMemo)
  const chat = useSelector(getChatMemo)
  
  const handleListItemClick = (companionId: string) => {
    dispatch(actionRightIsOpen(''))
    dispatch(asyncGetChatById(companionId))
    if(chat.companionId !== companionId) dispatch(actionScrollChat(true))
  }

  const handleNewMsgs = (e: React.MouseEvent<HTMLButtonElement, MouseEvent>, companionId: string) => {
    e.stopPropagation()
    dispatch(actionScrollChat(true))
    dispatch(actionRightIsOpen(''))
    dispatch(asyncGetChatById(companionId))
  }

  const handleNotification = useCallback((companionId: string) => {
    dispatch(asyncGetChatById(companionId))
    dispatch(actionScrollChat(true))
  }, [dispatch])

  const sortedChats: TChats = sortByRecent(chats, sort)
  
  useEffect(() => {
    const handleReset = () => dispatch(asyncGetChats())
    handleReset()
    const idInterval = setInterval(handleReset, refreshAppTime);
    return () => clearInterval(idInterval);
  }, [dispatch]);  

  useEffect(() => {
    if (chatsRef.current) {
      chatsRef.current.forEach(({total,seen}: any,i:number) => {
        const oldDifferent = total - seen
        const chat = sortedChats[i]
        if(chat === undefined) return
        const newDifferent = chat.total - chat.seen
        if (newDifferent > oldDifferent && !chat.mute) {
          playNotificationWithoutPermission(`${prodBaseURL}/telegramReceive.mp3`)
          notification(chat.name,() => handleNotification(chat.companionId))
        } 
      })
    }
    chatsRef.current = sortedChats
  }, [chat,sortedChats,handleNotification,dispatch])

  return total !== '0' ? (
    <List className={classes.list} component="nav"
      aria-label="main mailbox folders">
      {sortedChats.map((el) => <ChatItem key={el.number} chat={el}  
      handleListItemClick={handleListItemClick} handleNewMsgs={handleNewMsgs} />)}
    </List>
  ):<AlertInfo name='You do not have Chats yet!' />;
}

export default ChatsList